@@ -91,7 +91,7 @@ prhead_task(sw)
 		goto retry;
 	}
 	saved_sw_task = sw;
-	mprintf(SPTR" S   PID   SID   UID  EUID "SPTR" NAME             FLAGS\n",
+	mprintf(SPTR" S   PID  SESS   UID  EUID "SPTR" NAME             FLAGS\n",
 		"ADDR", p);
 }
 
@@ -153,12 +153,13 @@ print_task(addr, full)
 	mprintf("\ttimes:      %lx %lx - %lx %lx\n",
 		ts.utime, ts.stime, ts.cutime, ts.cstime);
 	mprintf("\tstart_time: %llx\n", ts.start_time);
+	mprintf("\tcap:        %x\n", ts.cap_effective);
 	mprintf("\tuser:       " FPTR "  (user_struct)\n", ts.user);
 	mprintf("\ttty:        " FPTR "  (tty_struct)\n",  ts.tty);
 	mprintf("\tfs:         " FPTR "  (fs_struct)\n",   ts.fs);
 	mprintf("\tnamespace:  " FPTR "  (namespace)\n",   ts.namespace);
 	mprintf("\tthread:     %lx\n", addr + OFFSET(struct task_struct, thread));
-	mprintf("\tsignal:     " FPTR "\n", ts.signal);
+	mprintf("\tsignal:     " FPTR "  (signal_struct)\n", ts.signal);
 	mprintf("\tsighand:    " FPTR "  (sighand_struct)\n", ts.sighand);
 	mprintf("\tblocked:    %08lx\n", ts.blocked.sig[0]);
 	mprintf("\tpending:    %08lx\n", ts.pending.signal.sig[0]);
@@ -376,6 +377,29 @@ print_sighand_struct(addr)
 	return 0;
 }
 
+void
+prhead_signal_struct()
+{
+	mprintf(SPTR" CNT "SPTR"  GX GXT "SPTR" NTF_CNT GSC\n",
+		"ADDR", "CURR_TGT", "G_X_TASK");
+}
+
+addr_t
+print_signal_struct(addr)
+	addr_t addr;
+{
+	struct signal_struct sig;
+
+	memread(addr, sizeof(sig), &sig, "signal_struct");
+	mprintf(FPTR " %3x " FPTR " ", addr,
+		ATOMIC_READ(sig.count), sig.curr_target);
+	mprintf("%3x %3x " FPTR " %7x %3x",
+		sig.group_exit, sig.group_exit_code,
+		sig.group_exit_task, sig.notify_count, sig.group_stop_count);
+	mprintf("\n");
+	return 0;
+}
+
 void
 prhead_user_struct()
 {
