@@ -28,6 +28,7 @@ extern const commandtable_t
 	command_request_queue,
 	command_rtable,
 	command_sighand_struct,
+	command_signal_struct,
 	command_slab,
 	command_sock,
 	command_socket,
@@ -73,6 +74,7 @@ const commandtable_t *commandtable_vers[] = {
 	&command_request_queue,
 	&command_rtable,
 	&command_sighand_struct,
+	&command_signal_struct,
 	&command_slab,
 	&command_sock,
 	&command_socket,
